

Installation
----------------------

- Conda installation is probbly the easiest.

  .. code-block:: bash
  
     conda install -c dja001 domutils 

- Pip installation should also work

  .. code-block:: bash
  
     pip install domutils

- To use the domutils modules in your python code, load the different modules separately. 
  For example:

  >>> import domutils.legs as legs            #doctest:+SKIP 
  >>> import domutils.geo_tools as geo_tools  #doctest:+SKIP 



